@@ -9,9 +9,11 @@ import petab.visualize.
 
 from .plot_data_and_simulation import (plot_data_and_simulation,
                                        plot_petab_problem,
-                                       plot_measurements_by_observable)
+                                       plot_measurements_by_observable,
+                                       save_vis_spec)
 
 __all__ = ["plot_data_and_simulation",
            "plot_petab_problem",
-           "plot_measurements_by_observable"
+           "plot_measurements_by_observable",
+           "save_vis_spec"
            ]
